@@ -14,8 +14,10 @@
 
 """Rikai-implemented PyTorch models and executors."""
 
+import rikai.pytorch.models.convnext
 import rikai.pytorch.models.efficientnet
 import rikai.pytorch.models.fasterrcnn
+import rikai.pytorch.models.feature_extractor
 import rikai.pytorch.models.keypointrcnn
 import rikai.pytorch.models.maskrcnn
 import rikai.pytorch.models.resnet
