@@ -22,8 +22,10 @@ from numbers import Real
 from typing import List, Optional, Sequence, Tuple, Union
 
 import numpy as np
+from pandas import get_option
 from PIL import Image, ImageDraw
 
+from rikai import CONF_RIKAI_VIZ_COLOR
 from rikai.mixin import Drawable, ToDict, ToNumpy
 from rikai.spark.types.geometry import (
     Box2dType,
@@ -392,6 +394,40 @@ class Box2d(ToNumpy, Sequence, ToDict, Drawable):
             return iou_arr[0]
         return iou_arr
 
+    def with_label(
+        self, text: str, color: str = get_option(CONF_RIKAI_VIZ_COLOR)
+    ) -> "rikai.viz.Draw":
+        from rikai.viz import Draw, Text
+
+        """return a `rikai.viz.Draw`, which contains a label,
+        used as a convenient tool to give a box a label
+        in visualization.
+        Parameters
+        ----------
+        text: str
+            The text content of that label
+        color: str
+            The color of the text,
+            will have a default value if not given.
+        Returns
+        -------
+        box_with_label
+            rikai.viz.Draw
+        """
+        # TODO add font size
+        return Draw(
+            [
+                self,
+                Text(
+                    # `ymin - 10` to let the label don't overlap
+                    # with box by default find a better way later
+                    text,
+                    (int(self.xmin), int(max(self.ymin - 10, 0))),
+                    color,
+                ),
+            ]
+        )
+
 
 class Box3d(ToNumpy, ToDict):
     """A 3-D bounding box
@@ -645,7 +681,7 @@ class Mask(ToNumpy, ToDict, Drawable):
 
     def to_dict(self) -> dict:
         ret = {
-            "type": self.type.value,
+            "type": self.type.name.lower(),
             "width": self.width,
             "height": self.height,
             "data": self.data,
